Async-aware automatic dependency injection backed by inventory.
Structs
- Container
- Lazy
- Resolves a dependency on first access and caches it locally.
- Provider
- Resolves a dependency each time
Provider::getis called. - Request
Context - Resolution
Context
Enums
Traits
- Configuration
Properties - Binds a strongly typed configuration value from the environment.
Functions
- global_
container - resolve
- set_
resolution_ error_ handler - Installs the process-wide handler used when a plain
#[injected]wrapper cannot resolve one of its dependencies.