Crate auto_di

Crate auto_di 

Async-aware automatic dependency injection backed by inventory.

Structs

Container
Lazy
Resolves a dependency on first access and caches it locally.
Provider
Resolves a dependency each time Provider::get is called.
RequestContext
ResolutionContext

Enums

DiError
Scope

Traits

ConfigurationProperties
Binds a strongly typed configuration value from the environment.

Functions

global_container
resolve
set_resolution_error_handler
Installs the process-wide handler used when a plain #[injected] wrapper cannot resolve one of its dependencies.

Type Aliases

BoxFuture
DynArc

Attribute Macros

application
configuration
configuration_properties
injectable
injected
provider
qualifier
singleton