Structs
Enums
Traits
Functions
Type Aliases
Attribute Macros
- application
- Boots the global context, creates eager beans, and runs shutdown hooks.
- bean
- Registers a standalone bean, or is consumed as a bean marker when nested
inside a
#[configuration]impl. - beans
- Registers
#[bean]methods from any ordinary impl block. The owner is a singleton created throughDefault, allowing&selfbean methods. - component
- configuration
- Registers all
#[bean]methods in an inherent impl as singleton providers. The configuration object is itself a singleton created throughDefault. - configuration_
properties - Generates environment binding and registers the resulting struct as a bean.
- qualifier
- Marker consumed from constructor parameters by the surrounding provider macro.
- repository
- service
- singleton
- Registers a lazily-created singleton provider.