Structs
Enums
Traits
Functions
Type Aliases
Attribute Macros
- application
- Boots the global context, creates eager beans, and runs shutdown hooks.
- bean
- Marker attribute consumed by
#[configuration]. - component
- configuration
- Registers all
#[bean]methods in an inherent impl as singleton providers. The configuration object is itself a singleton created throughDefault. - configuration_
properties - Generates environment binding and registers the resulting struct as a bean.
- qualifier
- Marker consumed from constructor parameters by the surrounding provider macro.
- repository
- service
- singleton
- Registers a lazily-created singleton provider.