pub struct Container { /* private fields */ }Implementations
Sourceimpl Container
impl Container
pub fn new() -> Result<Self, DiError>
pub fn with_profiles( profiles: impl IntoIterator<Item = impl Into<String>>, ) -> Result<Self, DiError>
pub async fn resolve<T>(&self) -> Result<Arc<T>, DiError>
pub async fn resolve_named<T>(&self, name: &str) -> Result<Arc<T>, DiError>
pub async fn resolve_optional<T>(&self) -> Result<Option<Arc<T>>, DiError>
pub async fn resolve_all<T>(&self) -> Result<Vec<Arc<T>>, DiError>
pub fn request_context(&self) -> RequestContext<'_>
pub async fn initialize_eager(&self) -> Result<(), DiError>
Sourcepub async fn validate(&self) -> Result<(), DiError>
pub async fn validate(&self) -> Result<(), DiError>
Validates the active singleton graph by constructing every singleton. This surfaces missing, ambiguous, circular, and invalid-scope dependencies during application startup instead of on the first request.
pub async fn shutdown(&self) -> Result<(), DiError>